# AH Persona Lite

A lite plugin module for persona management and image generation in the AgentHost (AH) framework.

## About

This plugin is designed to work with the AgentHost framework, which can be found at https://github.com/runvnc/ah.

## Installation

This plugin should be installed using the Plugin Manager on the AgentHost admin screen.

## Features

- Retrieve persona data from JSON files
- Generate images of personas based on descriptions

## Usage

Once installed via the Plugin Manager, the plugin will be automatically loaded by the AH system. You can use the following services and commands:

- `get_persona_data`: Retrieve data for a specific persona
- `pic_of_me`: Generate an image of the current persona

Refer to the AgentHost documentation and function docstrings for more detailed usage information.
